@@ -14,8 +14,10 @@
 import logging
 
 from graphql import GraphQLField
-from qctrlcommons.node.registry import NODE_REGISTRY
-from qctrlcommons.node.types import TYPE_REGISTRY
+from qctrlcommons.node.registry import (
+    NODE_REGISTRY,
+    TYPE_REGISTRY,
+)
 
 from .async_result import AsyncResult
 from .client_builder import (
